.. :changelog:

Changelog
---------

0.1.1 2015-01-09
================
* Bug Fix: remove duplicate hits when rate limits are stacked.
* Bug Fix: multiple rate limits returned by dynamic limits weren't respected.
* Documentation tweaks.

0.1.0 2015-01-09
================
* first release.



























